A value drawn from a parameter sweep over an evenly spaced sequence of numbers over a specified interval as in numpy.linspace(start,stop,num). The value drawn from the sequence is determined by taking the current run number modulo the number of elements in the sequence (num) and using that as an index into the sequence
* "start" - The starting value of the sequence
* "stop" - The ending value of the sequence
* "num" - Number of sequence values to generate